@@ -45,6 +45,8 @@
 #include <glib.h>
 #include <glib/gstdio.h>
 
+#include <libgssdp/gssdp-enums.h>
+
 #include "gupnp.h"
 
 #ifdef HAVE_IFADDRS_H
@@ -64,6 +66,8 @@
 struct _GUPnPContextManagerPrivate {
         guint              port;
         GSocketFamily      family;
+        GSSDPUDAVersion    uda_version;
+        gint32             boot_id;
 
         GUPnPContextManager *impl;
 
@@ -82,6 +86,7 @@ enum {
         PROP_0,
         PROP_PORT,
         PROP_SOCKET_FAMILY,
+        PROP_UDA_VERSION,
         PROP_WHITE_LIST
 };
 
@@ -93,6 +98,21 @@ enum {
 
 static guint signals[SIGNAL_LAST];
 
+static gint32
+handle_update (GUPnPRootDevice *root_device)
+{
+        gint32 boot_id;
+        GSSDPResourceGroup *group = NULL;
+        GSSDPClient *client = NULL;
+
+        group = gupnp_root_device_get_ssdp_resource_group (root_device);
+        client = gssdp_resource_group_get_client (group);
+        g_object_get (G_OBJECT (client), "boot-id", &boot_id, NULL);
+        gssdp_resource_group_update (group, ++boot_id);
+
+        return boot_id;
+}
+
 static void
 on_context_available (GUPnPContextManager    *manager,
                       GUPnPContext           *context,
@@ -100,6 +120,7 @@ on_context_available (GUPnPContextManager    *manager,
 {
         GUPnPWhiteList *white_list;
         GUPnPContextManagerPrivate *priv;
+        gboolean enabled = TRUE;
 
         priv = gupnp_context_manager_get_instance_private (manager);
 
@@ -116,11 +137,37 @@ on_context_available (GUPnPContextManager    *manager,
 
                 /* Make sure we don't send anything on now blocked network */
                 g_object_set (context, "active", FALSE, NULL);
+                enabled = FALSE;
 
                 /* Save it in case we need to re-enable it */
                 priv->blacklisted = g_list_prepend (priv->blacklisted,
                                                     g_object_ref (context));
         }
+
+        /* Ignore the boot-id handling for UDA 1.0 */
+        if (priv->uda_version == GSSDP_UDA_VERSION_1_0)
+                return;
+
+        if (enabled) {
+                /* We have a new context, so we need to send ssdp:update and
+                 * re-announce on the old clients */
+                GList *l = priv->objects;
+                gint32 boot_id = -1;
+
+                while (l) {
+                        if (GUPNP_IS_ROOT_DEVICE (l->data)) {
+                                boot_id = handle_update (GUPNP_ROOT_DEVICE (l->data));
+                        }
+                        l = l->next;
+                }
+
+                if (boot_id > -1) {
+                        priv->boot_id = boot_id;
+                }
+        }
+
+        /* The new client gets the current boot-id */
+        gssdp_client_set_boot_id (GSSDP_CLIENT (context), priv->boot_id);
 }
 
 static void
@@ -178,6 +225,27 @@ on_context_unavailable (GUPnPContextManager    *manager,
                 g_object_unref (black->data);
                 priv->blacklisted = g_list_delete_link (priv->blacklisted,
                                                         black);
+        } else {
+                /* When UDA 1.0, ignore boot-id handling */
+                if (priv->uda_version > GSSDP_UDA_VERSION_1_0) {
+                        return;
+                }
+                /* We have lost a context, so we need to send ssdp:update and
+                 * re-announce on the old clients */
+                GList *l = priv->objects;
+                gint32 boot_id = -1;
+
+                while (l) {
+                        if (GUPNP_IS_ROOT_DEVICE (l->data)) {
+                                boot_id = handle_update (GUPNP_ROOT_DEVICE (l->data));
+                        }
+                        l = l->next;
+                }
+
+                if (boot_id > -1) {
+                        gssdp_client_set_boot_id (GSSDP_CLIENT (context), boot_id);
+                        priv->boot_id = boot_id;
+                }
         }
 }
 
@@ -201,9 +269,14 @@ gupnp_context_manager_filter_context (GUPnPWhiteList *white_list,
                 /* If the white list is empty, treat it as disabled */
                 if (check) {
                         GUPnPContext *context;
+                        const char *property = "context";
+
+                        if (GUPNP_IS_CONTROL_POINT (obj->data)) {
+                                property = "client";
+                        }
 
                         g_object_get (G_OBJECT (obj->data),
-                                      "context", &context,
+                                      property, &context,
                                       NULL);
 
                         match = gupnp_white_list_check_context (white_list,
@@ -306,6 +379,7 @@ gupnp_context_manager_init (GUPnPContextManager *manager)
 
         g_signal_connect_after (priv->white_list, "notify::enabled",
                                 G_CALLBACK (on_white_list_enabled_cb), manager);
+        priv->boot_id = time(NULL);
 }
 
 static void
@@ -327,6 +401,9 @@ gupnp_context_manager_set_property (GObject      *object,
         case PROP_SOCKET_FAMILY:
                 priv->family = g_value_get_enum (value);
                 break;
+        case PROP_UDA_VERSION:
+                priv->uda_version = g_value_get_enum (value);
+                break;
         default:
                 G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
                 break;
@@ -352,6 +429,9 @@ gupnp_context_manager_get_property (GObject    *object,
         case PROP_SOCKET_FAMILY:
                 g_value_set_enum (value, priv->family);
                 break;
+        case PROP_UDA_VERSION:
+                g_value_set_enum (value, priv->uda_version);
+                break;
         case PROP_WHITE_LIST:
                 g_value_set_object (value, priv->white_list);
                 break;
@@ -447,6 +527,26 @@ gupnp_context_manager_class_init (GUPnPContextManagerClass *klass)
                                     G_PARAM_CONSTRUCT_ONLY |
                                     G_PARAM_STATIC_STRINGS));
 
+        /**
+         * GUPnPContextManager:uda-version:
+         *
+         * The UDA version the contexts will support. Use %GSSDP_UDA_VERSION_UNSPECIFIED
+         * for using the default UDA version.
+         *
+         * Since: 1.1.2
+         **/
+        g_object_class_install_property
+                (object_class,
+                 PROP_UDA_VERSION,
+                 g_param_spec_enum ("uda-version",
+                                    "UDA version",
+                                    "UDA version the created contexts will implement",
+                                    GSSDP_TYPE_UDA_VERSION,
+                                    GSSDP_UDA_VERSION_UNSPECIFIED,
+                                    G_PARAM_READWRITE |
+                                    G_PARAM_CONSTRUCT_ONLY |
+                                    G_PARAM_STATIC_STRINGS));
+
          /**
          * GUPnPContextManager:white-list:
          *
@@ -515,7 +615,7 @@ gupnp_context_manager_class_init (GUPnPContextManagerClass *klass)
  * NetworkManager - on its availability during runtime. If it is not available,
  * the implementation falls back to the basic Unix context manager instead.
  *
- * Equivalent to calling #gupnp_context_manager_create_full (%G_SOCKET_FAMILY_IPV4, port);
+ * Equivalent to calling #gupnp_context_manager_create_full (%GSSDP_UDA_VERSION_1_0, %G_SOCKET_FAMILY_IPV4, port);
  *
  * Returns: (transfer full): A new #GUPnPContextManager object.
  *
@@ -524,12 +624,16 @@ gupnp_context_manager_class_init (GUPnPContextManagerClass *klass)
 GUPnPContextManager *
 gupnp_context_manager_create (guint port)
 {
-        return gupnp_context_manager_create_full (G_SOCKET_FAMILY_IPV4, port);
+        return gupnp_context_manager_create_full (GSSDP_UDA_VERSION_1_0,
+                                                  G_SOCKET_FAMILY_IPV4,
+                                                  port);
 }
 
 /**
  * gupnp_context_manager_create_full:
- * @family: GSocketFamily to create the context for
+ * @uda_version: #GSSDPUDAVersion the created contexts should implement
+ * (UDA 1.0 or 1.1). For %GSSDP_UDA_VERSION_UNSPECIFIED for default.
+ * @family: #GSocketFamily to create the context for
  * @port: Port to create contexts for, or 0 if you don't care what port is used.
  *
  * Factory-method to create a new #GUPnPContextManager. The final type of the
@@ -542,7 +646,7 @@ gupnp_context_manager_create (guint port)
  * Since: 1.1.0
  **/
 GUPnPContextManager *
-gupnp_context_manager_create_full (GSocketFamily family, guint port)
+gupnp_context_manager_create_full (GSSDPUDAVersion uda_version, GSocketFamily family, guint port)
 {
 #if defined(USE_NETWORK_MANAGER) || defined (USE_CONNMAN)
         GDBusConnection *system_bus;
@@ -590,6 +694,8 @@ gupnp_context_manager_create_full (GSocketFamily family, guint port)
         g_debug ("Using context manager implementation %s",
                  g_type_name (impl_type));
         impl = GUPNP_CONTEXT_MANAGER (g_object_new (impl_type,
+                                                    "family", family,
+                                                    "uda-version", uda_version,
                                                     "port", port,
                                                     NULL));
 
@@ -728,6 +834,16 @@ gupnp_context_manager_get_white_list (GUPnPContextManager *manager)
         return priv->white_list;
 }
 
+/**
+ * gupnp_context_manager_get_socket_family:
+ * @manager: A #GUPnPContextManager
+ *
+ * Get the #GSocketFamily the contexts are created for. Can be
+ * %G_SOCKET_FAMILY_IPV6, %G_SOCKET_FAMILY_IPV4 or %G_SOCKET_FAMILY_INVALID for
+ * both
+ *
+ * Returns: The socket family
+ */
 GSocketFamily
 gupnp_context_manager_get_socket_family (GUPnPContextManager *manager)
 {
@@ -740,3 +856,24 @@ gupnp_context_manager_get_socket_family (GUPnPContextManager *manager)
 
         return priv->family;
 }
+
+/**
+ * gupnp_context_manager_get_uda_version:
+ * @manager: A #GUPnPContextManager
+ *
+ * Get the UDA protocol version the contexts are implementing
+ *
+ * Returns: The UDA protocol version
+ */
+GSSDPUDAVersion
+gupnp_context_manager_get_uda_version (GUPnPContextManager *manager)
+{
+        GUPnPContextManagerPrivate *priv;
+
+        g_return_val_if_fail (GUPNP_IS_CONTEXT_MANAGER (manager),
+                              GSSDP_UDA_VERSION_UNSPECIFIED);
+
+        priv = gupnp_context_manager_get_instance_private (manager);
+
+        return priv->uda_version;
+}
