@@ -55,7 +55,8 @@ GUPnPContextManager *
 gupnp_context_manager_create            (guint port);
 
 GUPnPContextManager *
-gupnp_context_manager_create_full       (GSocketFamily   family,
+gupnp_context_manager_create_full       (GSSDPUDAVersion uda_version,
+                                         GSocketFamily   family,
                                          guint           port);
 
 void
@@ -64,13 +65,13 @@ gupnp_context_manager_rescan_control_points
 
 void
 gupnp_context_manager_manage_control_point
-                                        (GUPnPContextManager     *manager,
-                                         GUPnPControlPoint       *control_point);
+                                        (GUPnPContextManager *manager,
+                                         GUPnPControlPoint   *control_point);
 
 void
 gupnp_context_manager_manage_root_device
-                                        (GUPnPContextManager     *manager,
-                                         GUPnPRootDevice         *root_device);
+                                        (GUPnPContextManager *manager,
+                                         GUPnPRootDevice     *root_device);
 
 guint
 gupnp_context_manager_get_port          (GUPnPContextManager *manager);
@@ -81,6 +82,9 @@ gupnp_context_manager_get_white_list    (GUPnPContextManager *manager);
 GSocketFamily
 gupnp_context_manager_get_socket_family (GUPnPContextManager *manager);
 
+GSSDPUDAVersion
+gupnp_context_manager_get_uda_version   (GUPnPContextManager *manager);
+
 G_END_DECLS
 
 #endif /* GUPNP_CONTEXT_MANAGER_H */
