@@ -19,8 +19,8 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __GUPNP_CONTEXT_PRIVATE_H__
-#define __GUPNP_CONTEXT_PRIVATE_H__
+#ifndef GUPNP_CONTEXT_PRIVATE_H
+#define GUPNP_CONTEXT_PRIVATE_H
 
 #include <libsoup/soup.h>
 
@@ -36,9 +36,6 @@ _gupnp_context_add_server_handler_with_data (GUPnPContext *context,
                                              const char *path,
                                              AclServerHandler *data);
 
-G_GNUC_INTERNAL gboolean
-gupnp_context_ip_is_ours (GUPnPContext *context, const char *address);
-
 G_END_DECLS
 
-#endif /* __GUPNP_CONTEXT_PRIVATE_H__ */
+#endif /* GUPNP_CONTEXT_PRIVATE_H */
