@@ -127,23 +127,29 @@ typedef struct {
 
 static GInitableIface* initable_parent_iface = NULL;
 
+static const char *GSSDP_UDA_VERSION_STRINGS[] = {
+        [GSSDP_UDA_VERSION_1_0] = "1.0",
+        [GSSDP_UDA_VERSION_1_1] = "1.1"
+};
+
 /*
- * Generates the default server ID.
- **/
+ * Generates the default server ID
+ */
 static char *
-make_server_id (void)
+make_server_id (GSSDPUDAVersion uda_version)
 {
 #ifdef G_OS_WIN32
         OSVERSIONINFO versioninfo;
         versioninfo.dwOSVersionInfoSize = sizeof (OSVERSIONINFO);
         if (GetVersionEx (&versioninfo)) {
-                return g_strdup_printf ("Microsoft Windows/%ld.%ld"
-                                        " UPnP/1.0 GUPnP/%s",
+                return g_strdup_printf ("Microsoft Windows/%ld.%ld UPnP/%s GUPnP/%s",
                                         versioninfo.dwMajorVersion,
                                         versioninfo.dwMinorVersion,
+                                        GSSDP_UDA_VERSION_STRINGS[uda_version],
                                         VERSION);
         } else {
-                return g_strdup_printf ("Microsoft Windows UPnP/1.0 GUPnP/%s",
+                return g_strdup_printf ("Microsoft Windows/Unknown UPnP/%s GUPnP/%s",
+                                        GSSDP_UDA_VERSION_STRINGS[uda_version],
                                         VERSION);
         }
 #else
@@ -151,21 +157,16 @@ make_server_id (void)
 
         uname (&sysinfo);
 
-        return g_strdup_printf ("%s/%s UPnP/1.0 GUPnP/%s",
+        return g_strdup_printf ("%s/%s UPnP/%s GUPnP/%s",
                                 sysinfo.sysname,
                                 sysinfo.release,
+                                GSSDP_UDA_VERSION_STRINGS[uda_version],
                                 VERSION);
 #endif
 }
-
 static void
 gupnp_context_init (GUPnPContext *context)
 {
-        char *server_id;
-
-        server_id = make_server_id ();
-        gssdp_client_set_server_id (GSSDP_CLIENT (context), server_id);
-        g_free (server_id);
 }
 
 static gboolean
@@ -174,9 +175,11 @@ gupnp_context_initable_init (GInitable     *initable,
                              GError       **error)
 {
         char *user_agent;
+        char *server_id;
         GError *inner_error = NULL;
         GUPnPContext *context;
         GUPnPContextPrivate *priv;
+        GSSDPUDAVersion version;
 
         if (!initable_parent_iface->init(initable,
                                          cancellable,
@@ -189,6 +192,11 @@ gupnp_context_initable_init (GInitable     *initable,
         context = GUPNP_CONTEXT (initable);
         priv = gupnp_context_get_instance_private (context);
 
+        version = gssdp_client_get_uda_version (GSSDP_CLIENT (context));
+        server_id = make_server_id (version);
+        gssdp_client_set_server_id (GSSDP_CLIENT (context), server_id);
+        g_free (server_id);
+
         priv->session = soup_session_new ();
 
         user_agent = g_strdup_printf ("%s GUPnP/" VERSION " DLNADOC/1.50",
@@ -1381,6 +1389,9 @@ gupnp_context_unhost_path (GUPnPContext *context,
  * gupnp_context_get_acl:
  * @context: A #GUPnPContext
  *
+ * Access the #GUPnPAcl associated with this client. If there isn't any,
+ * retturns %NULL. The returned ACL must not be freed.
+ *
  * Returns:(transfer none): The access control list associated with this context or %NULL
  * if no acl is set.
  *
@@ -1403,6 +1414,9 @@ gupnp_context_get_acl (GUPnPContext *context)
  * @acl: (allow-none): The new access control list or %NULL to remove the
  * current list.
  *
+ * Attach or remove the assoicated access control list to this context. If
+ * @acl is %NULL, the current access control list will be removed.
+ *
  * Since: 0.20.11
  **/
 void
@@ -1413,10 +1427,7 @@ gupnp_context_set_acl (GUPnPContext *context, GUPnPAcl *acl)
         g_return_if_fail (GUPNP_IS_CONTEXT (context));
 
         priv = gupnp_context_get_instance_private (context);
-        if (priv->acl != NULL) {
-                g_object_unref (priv->acl);
-                priv->acl = NULL;
-        }
+        g_clear_object (&priv->acl);
 
         if (acl != NULL)
                 priv->acl = g_object_ref (acl);
@@ -1603,10 +1614,13 @@ gupnp_context_remove_server_handler (GUPnPContext *context, const char *path)
  * @context: a #GUPnPContext
  * @uri: an uri to rewrite if necessary
  *
+ * Utility function to re-write an uri to the IPv6 link-local form which has
+ * the zone index appended to the IP address.
+ *
  * Returns: A re-written version of the @uri if the context is on a link-local
  * IPv6 address, a copy of the @uri otherwise.
  *
- * Since: 1.11.1
+ * Since: 1.1.1
  */
 char *
 gupnp_context_rewrite_uri (GUPnPContext *context, const char *plain_uri)
